broadcast

Function broadcast 

pub(super) fn broadcast<W: Word>(
    block: &[u8],
) -> Array<Block, <W as Word>::Blocks>
Replicate a single 16-byte input block across all slots of a Batch<W>.

Used by the key schedules, which conceptually call bitslice(...) on the same input block several times to fill the bitsliced state.