pub(super) fn xor_columns<W: Word>(
rkeys: &mut [W],
offset: usize,
idx_xor: usize,
idx_ror: u32,
)Expand description
XOR the columns after the S-box during the key schedule round function.
The idx_xor parameter refers to the index of the previous round key
involved in the XOR computation (should be 8 and 16 for AES-128 and AES-256,
respectively).
The idx_ror parameter refers to the rotation value, which varies between the
different key schedules.